///////////////////////////////////////////////////////////////////////////
// Name:    FontCombo.pas                                                //
// Version: 1.0.                                                         //
// Author:  Rasmus Klitgaard-Nielsen                                     //
// Desc.:   Combobox to select Fonts visually.                           //
//           Gives fontname in "fontname" property                       //
///////////////////////////////////////////////////////////////////////////
// (C) 1999 Rasmus Klitgaard-Nielsen                                     //
// (C) 1999 JograData (www.jogradata.dk)                                 //
///////////////////////////////////////////////////////////////////////////

unit FontCombo;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls;

type
  TFontCombo = class(TCustomComboBox)
  private
    function GetSelection: String;
    procedure SetSelection(Value: String);
  protected
    procedure SetStyle(Value: TComboBoxStyle); override;
    procedure DrawItem(Index: Integer; Rect: TRect;
      State: TOwnerDrawState); override;
    procedure CreateWnd; override;
  public
    constructor Create(AOwner: TComponent); override;
    property FontName: String read GetSelection write SetSelection;
  published
    property Color;
    property Ctl3D;
    property DragMode;
    property DragCursor;
    property DropDownCount;
    property Enabled;
    property Font;
    property ItemHeight;
    property Items;
    property MaxLength;
    property ParentColor;
    property ParentCtl3D;
    property ParentFont;
    property ParentShowHint;
    property PopupMenu;
    property ShowHint;
    property Sorted;
    property TabOrder;
    property TabStop;
    property Text;
    property Visible;
    property OnChange;
    property OnClick;
    property OnDblClick;
    property OnDragDrop;
    property OnDragOver;
    property OnDrawItem;
    property OnDropDown;
    property OnEndDrag;
    property OnEnter;
    property OnExit;
    property OnKeyDown;
    property OnKeyPress;
    property OnKeyUp;
    property OnMeasureItem;
    property OnStartDrag;
  end;

procedure Register;

implementation

////////////////////////////////////////////////////////////////////////////////
// public Globals
//

procedure Register;
begin
  RegisterComponents('Additional', [TFontCombo]);
end;

////////////////////////////////////////////////////////////////////////////////
// private TFontCombo
//

function TFontCombo.GetSelection: String;
begin
  if ItemIndex >= 0 then
    result:=Items[ItemIndex]
  else
    result:='';
end;

procedure TFontCombo.SetSelection(Value: String);
var
  c: integer;
  i: Longint;
begin
  ItemIndex := -1;

  for c := 0 to Items.count do
    if Items[c]=Value then
        ItemIndex := c;
end;

////////////////////////////////////////////////////////////////////////////////
// protected TFontCombo
//

procedure TFontCombo.SetStyle(Value: TComboBoxStyle);
begin
  inherited SetStyle(csOwnerDrawFixed);
end;

procedure TFontCombo.DrawItem(Index: Integer; Rect: TRect; State: TOwnerDrawState);
begin
  canvas.Font.Name:=items[index];
  canvas.fillrect(rect);
  canvas.TextOut(rect.left,rect.top,items[index]);
  inherited DrawItem(Index, Rect, State);
end;

procedure TFontCombo.CreateWnd;
begin
  inherited CreateWnd;
  items.Assign(screen.fonts);
end;

////////////////////////////////////////////////////////////////////////////////
// public TFontCombo
//

constructor TFontCombo.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  Style := csOwnerDrawFixed;
end;
end.
